

/**
 * Classe que implementa e encapsula a comunicao do java com a 
 * <code>dll</code> que contem as funes de acesso e manipulao
 * ao lxico criada em C++. 
 * @author Marcelo C. M. Muniz
 *
 */
public class MyLexicon {
	private native int CarregaDicionario(String path_dic, String path_alph);
	private native void LiberaDicionario();
	private native String DescompactaEntrada(String entrada);
	private boolean carregado;


    static {
        System.loadLibrary("lexicon_jni");
    }
    
	/**
	 * A rotina 'CarregaDic' carrega o dicionrio compactado.
	 * @param path_dic Deve fornecer a localizao (absoluta ou
	 * relativa) do arquivo que contm este dicionrio. O arquivo com os
	 * cdigos de flexo, deve estar no mesma mesma localizao mas deve ter
	 * a extenso .inf ao contrrio de .bin do dicionrio compactado.
	 * @param path_alph Deve fornecer a localizao (absoluta ou
	 * relativa) do arquivo que contm o alfabeto.
	 * @return Devolve um cdigo de controle:<br>
	 * 0 - Trmino normal da operao.<br>
	 * 1 - Erro na abertura de arquivo do alphabeto.<br>
	 * 2 - Erro na abertura de arquivo dic.bin<br>
	 * 3 - Erro na abertura de arquivo dic.inf
	 */
	public int CarregaDic(String path_dic, String path_alph){
		if (carregado == true) LiberaDicionario();  
		int i = CarregaDicionario(path_dic, path_alph);
		if (i ==0) carregado = true;
		return i;
	}
	
	/**
	 * Desaloca o dicionrio carregado da memria.
	 *
	 */
	public void LiberaDic(){
		LiberaDicionario();
		carregado = false;	
	};
	
	/**
	 * Funo que descompacta uma entrada do dicionrio.
	 * @param entrada Entrada a ser descompactada.
	 * @return Devolve uma <code>String</code> com todas as possveis 
	 * classificaes da entrada. As classificaes so separadas por ";" e 
	 * caso no exista essa entrada ser devolvido uma String vazia, isto ,
	 * o primeiro caracter ser "<code>\0</code>".
	 */
	public String DescompEntrada(String entrada){
		return DescompactaEntrada(entrada);
	};

	protected void finalize(){
		if (carregado == true) LiberaDicionario();  
	}
    
    
}
